<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
				xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
				xmlns:op="utc.fr:ics/opale3"
				xmlns:date="http://xml.apache.org/xalan/java/java.util.Date" 
				xmlns:java="http://xml.apache.org/xslt/java"
				extension-element-prefixes="date"
				exclude-result-prefixes="sc sp op java">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />
	

	<xsl:template name="tMeta">
		<xsl:apply-templates select="sp:info/op:info/sp:cpyrgt | sp:info/op:info/sp:cc"/><!-- message de non récupération -->
		<AUTEURS>
			<xsl:choose>
				<xsl:when test="sp:info/op:info/sp:dc/op:dc/sp:auth">
					<xsl:apply-templates select="sp:info/op:info/sp:dc/op:dc/sp:auth"/>
				</xsl:when>
				<xsl:otherwise>
					<AUTEUR nom="" prenom="" fonction="" organisme=""/>
					<xsl:call-template name="tLogError">
						<xsl:with-param name="pMessage">Un auteur est requis pour chaque item d&apos;UVED.</xsl:with-param>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</AUTEURS>
		<DATECRE>
			<xsl:choose>
				<xsl:when test="sp:info/op:info/sp:dc/op:dc/sp:date">
					<xsl:apply-templates select="sp:info/op:info/sp:dc/op:dc/sp:date"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="vDate" select="date:new()" />
					<xsl:variable name="vFormatter" select="java:java.text.SimpleDateFormat.new('dd/MM/yyyy')"/>
					<xsl:value-of select="java:format($vFormatter, $vDate)"/>
					<xsl:call-template name="tLogError">
						<xsl:with-param name="pMessage">Une date est requise pour chaque item d&apos;UVED.</xsl:with-param>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</DATECRE>
		<xsl:apply-templates select="sp:info/op:info/sp:dc/op:dc/sp:lang"/>
		<xsl:apply-templates select="sp:info/op:info/sp:dc/op:dc/sp:level"/>
		<xsl:apply-templates select="sp:info/op:info/sp:keywds"/>
		<xsl:apply-templates select="sp:info/op:info/sp:dc/op:dc/sp:cover/sp:spatial"/>
		<xsl:apply-templates select="sp:info/op:info/sp:dc/op:dc/*[name()!='sp:auth' and name()!='sp:date' and name()!='sp:lang' and name()!='sp:level' and name()!='sp:cover']"/><!-- message de non récupération -->
	</xsl:template>
	
	<xsl:template match="sp:keywds">
		<MOTSCLE>
			<xsl:for-each select="op:keywds/sp:keywd">
				<MOTCLE><xsl:value-of select="."/></MOTCLE>
			</xsl:for-each>
		</MOTSCLE>
	</xsl:template>
	
	<xsl:template match="sp:dc/op:dc/sp:auth">
	 	<AUTEUR nom="{.}" prenom="" fonction="" organisme="">
	 		<xsl:call-template name="tLogWarning">
				<xsl:with-param name="pMessage">Veuillez compléter la définition de l&apos;auteur : nom / prénom / fonction</xsl:with-param>
			</xsl:call-template>
	 	</AUTEUR>
	 </xsl:template>
	 
	 <xsl:template match="sp:dc/op:dc/sp:date">
	 	<xsl:value-of select="."/>
 		<xsl:call-template name="tLogWarning">
			<xsl:with-param name="pMessage">Formalisme de la date à vérifier (ex : 12/01/2008)</xsl:with-param>
		</xsl:call-template>
	 </xsl:template>
	 
	 <xsl:template match="sp:dc/op:dc/sp:lang[.!='OT']">
	 	<LANGUE>
	 		<xsl:choose>
	 			<xsl:when test=".='FR'">fra</xsl:when>
	 			<xsl:when test=".='EN'">eng</xsl:when>
	 		</xsl:choose>
	 	</LANGUE>
	 </xsl:template>
	 
	 <xsl:template match="sp:dc/op:dc/sp:level">
	 	<NIVEAULMD>
	 		<xsl:value-of select="."/>
	 	</NIVEAULMD>
	 </xsl:template>
	 
	 <xsl:template match="sp:dc/op:dc/sp:cover/sp:spatial">
	 	<LOCALISATION>
	 		<xsl:value-of select="."/>
	 	</LOCALISATION>
	 </xsl:template>
	 	 
	 <!-- Eléménets non gérés :
			- sp:cpyrgt
			- sp:cc
			- sp:dc/op:dc/* (sauf level, lang, date, auth)
	 -->
		
</xsl:stylesheet>